# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class CreateMonitorsRequest(AbstractModel):
    """CreateMonitors请求参数结构体

    """

    def __init__(self):
        """
        :param Urls: 站点的url列表\n        :type Urls: list of str\n        :param Name: 任务名称\n        :type Name: str\n        :param ScannerType: 扫描模式，normal-正常扫描；deep-深度扫描\n        :type ScannerType: str\n        :param Crontab: 扫描周期，单位小时，每X小时执行一次\n        :type Crontab: int\n        :param RateLimit: 扫描速率限制，每秒发送X个HTTP请求\n        :type RateLimit: int\n        :param FirstScanStartTime: 首次扫描开始时间\n        :type FirstScanStartTime: str\n        """
        self.Urls = None
        self.Name = None
        self.ScannerType = None
        self.Crontab = None
        self.RateLimit = None
        self.FirstScanStartTime = None


    def _deserialize(self, params):
        self.Urls = params.get("Urls")
        self.Name = params.get("Name")
        self.ScannerType = params.get("ScannerType")
        self.Crontab = params.get("Crontab")
        self.RateLimit = params.get("RateLimit")
        self.FirstScanStartTime = params.get("FirstScanStartTime")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateMonitorsResponse(AbstractModel):
    """CreateMonitors返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class CreateSitesRequest(AbstractModel):
    """CreateSites请求参数结构体

    """

    def __init__(self):
        """
        :param Urls: 站点的url列表\n        :type Urls: list of str\n        :param UserAgent: 访问网站的客户端标识\n        :type UserAgent: str\n        """
        self.Urls = None
        self.UserAgent = None


    def _deserialize(self, params):
        self.Urls = params.get("Urls")
        self.UserAgent = params.get("UserAgent")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateSitesResponse(AbstractModel):
    """CreateSites返回参数结构体

    """

    def __init__(self):
        """
        :param Number: 新增站点数。\n        :type Number: int\n        :param Sites: 站点数组\n        :type Sites: list of MiniSite\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Number = None
        self.Sites = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Number = params.get("Number")
        if params.get("Sites") is not None:
            self.Sites = []
            for item in params.get("Sites"):
                obj = MiniSite()
                obj._deserialize(item)
                self.Sites.append(obj)
        self.RequestId = params.get("RequestId")


class CreateSitesScansRequest(AbstractModel):
    """CreateSitesScans请求参数结构体

    """

    def __init__(self):
        """
        :param SiteIds: 站点的ID列表\n        :type SiteIds: list of int non-negative\n        :param ScannerType: 扫描模式，normal-正常扫描；deep-深度扫描\n        :type ScannerType: str\n        :param RateLimit: 扫描速率限制，每秒发送X个HTTP请求\n        :type RateLimit: int\n        """
        self.SiteIds = None
        self.ScannerType = None
        self.RateLimit = None


    def _deserialize(self, params):
        self.SiteIds = params.get("SiteIds")
        self.ScannerType = params.get("ScannerType")
        self.RateLimit = params.get("RateLimit")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateSitesScansResponse(AbstractModel):
    """CreateSitesScans返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class CreateVulsMisinformationRequest(AbstractModel):
    """CreateVulsMisinformation请求参数结构体

    """

    def __init__(self):
        """
        :param VulIds: 漏洞ID列表\n        :type VulIds: list of int non-negative\n        """
        self.VulIds = None


    def _deserialize(self, params):
        self.VulIds = params.get("VulIds")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateVulsMisinformationResponse(AbstractModel):
    """CreateVulsMisinformation返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class CreateVulsReportRequest(AbstractModel):
    """CreateVulsReport请求参数结构体

    """

    def __init__(self):
        """
        :param SiteId: 站点ID\n        :type SiteId: int\n        :param MonitorId: 监控任务ID\n        :type MonitorId: int\n        """
        self.SiteId = None
        self.MonitorId = None


    def _deserialize(self, params):
        self.SiteId = params.get("SiteId")
        self.MonitorId = params.get("MonitorId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateVulsReportResponse(AbstractModel):
    """CreateVulsReport返回参数结构体

    """

    def __init__(self):
        """
        :param ReportFileUrl: 报告下载地址\n        :type ReportFileUrl: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.ReportFileUrl = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ReportFileUrl = params.get("ReportFileUrl")
        self.RequestId = params.get("RequestId")


class DeleteMonitorsRequest(AbstractModel):
    """DeleteMonitors请求参数结构体

    """

    def __init__(self):
        """
        :param MonitorIds: 监控任务ID列表\n        :type MonitorIds: list of int non-negative\n        """
        self.MonitorIds = None


    def _deserialize(self, params):
        self.MonitorIds = params.get("MonitorIds")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DeleteMonitorsResponse(AbstractModel):
    """DeleteMonitors返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class DeleteSitesRequest(AbstractModel):
    """DeleteSites请求参数结构体

    """

    def __init__(self):
        """
        :param SiteIds: 站点ID列表\n        :type SiteIds: list of int non-negative\n        """
        self.SiteIds = None


    def _deserialize(self, params):
        self.SiteIds = params.get("SiteIds")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DeleteSitesResponse(AbstractModel):
    """DeleteSites返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class DescribeConfigRequest(AbstractModel):
    """DescribeConfig请求参数结构体

    """


class DescribeConfigResponse(AbstractModel):
    """DescribeConfig返回参数结构体

    """

    def __init__(self):
        """
        :param NoticeLevel: 漏洞告警通知等级，4位分别代表：高危、中危、低危、提示。\n        :type NoticeLevel: str\n        :param Id: 配置ID。\n        :type Id: int\n        :param CreatedAt: 记录创建时间。\n        :type CreatedAt: str\n        :param UpdatedAt: 记录更新新建。\n        :type UpdatedAt: str\n        :param Appid: 云用户appid。\n        :type Appid: int\n        :param ContentLevel: 内容检测通知等级-1:通知,0-不通知\n        :type ContentLevel: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.NoticeLevel = None
        self.Id = None
        self.CreatedAt = None
        self.UpdatedAt = None
        self.Appid = None
        self.ContentLevel = None
        self.RequestId = None


    def _deserialize(self, params):
        self.NoticeLevel = params.get("NoticeLevel")
        self.Id = params.get("Id")
        self.CreatedAt = params.get("CreatedAt")
        self.UpdatedAt = params.get("UpdatedAt")
        self.Appid = params.get("Appid")
        self.ContentLevel = params.get("ContentLevel")
        self.RequestId = params.get("RequestId")


class DescribeMonitorsRequest(AbstractModel):
    """DescribeMonitors请求参数结构体

    """

    def __init__(self):
        """
        :param MonitorIds: 监控任务ID列表\n        :type MonitorIds: list of int non-negative\n        :param Filters: 过滤条件\n        :type Filters: list of Filter\n        :param Offset: 偏移量，默认为0\n        :type Offset: int\n        :param Limit: 返回数量，默认为10，最大值为100\n        :type Limit: int\n        """
        self.MonitorIds = None
        self.Filters = None
        self.Offset = None
        self.Limit = None


    def _deserialize(self, params):
        self.MonitorIds = params.get("MonitorIds")
        if params.get("Filters") is not None:
            self.Filters = []
            for item in params.get("Filters"):
                obj = Filter()
                obj._deserialize(item)
                self.Filters.append(obj)
        self.Offset = params.get("Offset")
        self.Limit = params.get("Limit")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeMonitorsResponse(AbstractModel):
    """DescribeMonitors返回参数结构体

    """

    def __init__(self):
        """
        :param Monitors: 监控任务列表。\n        :type Monitors: list of MonitorsDetail\n        :param TotalCount: 监控任务数量。\n        :type TotalCount: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Monitors = None
        self.TotalCount = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Monitors") is not None:
            self.Monitors = []
            for item in params.get("Monitors"):
                obj = MonitorsDetail()
                obj._deserialize(item)
                self.Monitors.append(obj)
        self.TotalCount = params.get("TotalCount")
        self.RequestId = params.get("RequestId")


class DescribeSiteQuotaRequest(AbstractModel):
    """DescribeSiteQuota请求参数结构体

    """


class DescribeSiteQuotaResponse(AbstractModel):
    """DescribeSiteQuota返回参数结构体

    """

    def __init__(self):
        """
        :param Total: 已购买的扫描次数。\n        :type Total: int\n        :param Used: 已使用的扫描次数。\n        :type Used: int\n        :param Available: 剩余可用的扫描次数。\n        :type Available: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Total = None
        self.Used = None
        self.Available = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Total = params.get("Total")
        self.Used = params.get("Used")
        self.Available = params.get("Available")
        self.RequestId = params.get("RequestId")


class DescribeSitesRequest(AbstractModel):
    """DescribeSites请求参数结构体

    """

    def __init__(self):
        """
        :param SiteIds: 站点ID列表\n        :type SiteIds: list of int non-negative\n        :param Filters: 过滤条件\n        :type Filters: list of Filter\n        :param Offset: 偏移量，默认为0\n        :type Offset: int\n        :param Limit: 返回数量，默认为10，最大值为100\n        :type Limit: int\n        """
        self.SiteIds = None
        self.Filters = None
        self.Offset = None
        self.Limit = None


    def _deserialize(self, params):
        self.SiteIds = params.get("SiteIds")
        if params.get("Filters") is not None:
            self.Filters = []
            for item in params.get("Filters"):
                obj = Filter()
                obj._deserialize(item)
                self.Filters.append(obj)
        self.Offset = params.get("Offset")
        self.Limit = params.get("Limit")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeSitesResponse(AbstractModel):
    """DescribeSites返回参数结构体

    """

    def __init__(self):
        """
        :param TotalCount: 站点数量。\n        :type TotalCount: int\n        :param Sites: 站点信息列表。\n        :type Sites: list of Site\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.TotalCount = None
        self.Sites = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("Sites") is not None:
            self.Sites = []
            for item in params.get("Sites"):
                obj = Site()
                obj._deserialize(item)
                self.Sites.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeSitesVerificationRequest(AbstractModel):
    """DescribeSitesVerification请求参数结构体

    """

    def __init__(self):
        """
        :param Urls: 站点的url列表\n        :type Urls: list of str\n        """
        self.Urls = None


    def _deserialize(self, params):
        self.Urls = params.get("Urls")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeSitesVerificationResponse(AbstractModel):
    """DescribeSitesVerification返回参数结构体

    """

    def __init__(self):
        """
        :param TotalCount: 验证信息数量。\n        :type TotalCount: int\n        :param SitesVerification: 验证信息列表。\n        :type SitesVerification: list of SitesVerification\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.TotalCount = None
        self.SitesVerification = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("SitesVerification") is not None:
            self.SitesVerification = []
            for item in params.get("SitesVerification"):
                obj = SitesVerification()
                obj._deserialize(item)
                self.SitesVerification.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeVulsNumberRequest(AbstractModel):
    """DescribeVulsNumber请求参数结构体

    """


class DescribeVulsNumberResponse(AbstractModel):
    """DescribeVulsNumber返回参数结构体

    """

    def __init__(self):
        """
        :param ImpactSiteNumber: 受影响的网站总数。\n        :type ImpactSiteNumber: int\n        :param SiteNumber: 已验证的网站总数。\n        :type SiteNumber: int\n        :param VulsHighNumber: 高风险漏洞总数。\n        :type VulsHighNumber: int\n        :param VulsMiddleNumber: 中风险漏洞总数。\n        :type VulsMiddleNumber: int\n        :param VulsLowNumber: 低高风险漏洞总数。\n        :type VulsLowNumber: int\n        :param VulsNoticeNumber: 风险提示总数。\n        :type VulsNoticeNumber: int\n        :param PageCount: 扫描页面总数。\n        :type PageCount: int\n        :param Sites: 已验证的网站列表。\n        :type Sites: list of MonitorMiniSite\n        :param ImpactSites: 受影响的网站列表。\n        :type ImpactSites: list of MonitorMiniSite\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.ImpactSiteNumber = None
        self.SiteNumber = None
        self.VulsHighNumber = None
        self.VulsMiddleNumber = None
        self.VulsLowNumber = None
        self.VulsNoticeNumber = None
        self.PageCount = None
        self.Sites = None
        self.ImpactSites = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ImpactSiteNumber = params.get("ImpactSiteNumber")
        self.SiteNumber = params.get("SiteNumber")
        self.VulsHighNumber = params.get("VulsHighNumber")
        self.VulsMiddleNumber = params.get("VulsMiddleNumber")
        self.VulsLowNumber = params.get("VulsLowNumber")
        self.VulsNoticeNumber = params.get("VulsNoticeNumber")
        self.PageCount = params.get("PageCount")
        if params.get("Sites") is not None:
            self.Sites = []
            for item in params.get("Sites"):
                obj = MonitorMiniSite()
                obj._deserialize(item)
                self.Sites.append(obj)
        if params.get("ImpactSites") is not None:
            self.ImpactSites = []
            for item in params.get("ImpactSites"):
                obj = MonitorMiniSite()
                obj._deserialize(item)
                self.ImpactSites.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeVulsNumberTimelineRequest(AbstractModel):
    """DescribeVulsNumberTimeline请求参数结构体

    """


class DescribeVulsNumberTimelineResponse(AbstractModel):
    """DescribeVulsNumberTimeline返回参数结构体

    """

    def __init__(self):
        """
        :param TotalCount: 统计数据记录数量。\n        :type TotalCount: int\n        :param VulsTimeline: 用户漏洞数随时间变化统计数据。\n        :type VulsTimeline: list of VulsTimeline\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.TotalCount = None
        self.VulsTimeline = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("VulsTimeline") is not None:
            self.VulsTimeline = []
            for item in params.get("VulsTimeline"):
                obj = VulsTimeline()
                obj._deserialize(item)
                self.VulsTimeline.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeVulsRequest(AbstractModel):
    """DescribeVuls请求参数结构体

    """

    def __init__(self):
        """
        :param SiteId: 站点ID\n        :type SiteId: int\n        :param MonitorId: 监控任务ID\n        :type MonitorId: int\n        :param Filters: 过滤条件\n        :type Filters: list of Filter\n        :param Offset: 偏移量，默认为0\n        :type Offset: int\n        :param Limit: 返回数量，默认为10，最大值为100\n        :type Limit: int\n        """
        self.SiteId = None
        self.MonitorId = None
        self.Filters = None
        self.Offset = None
        self.Limit = None


    def _deserialize(self, params):
        self.SiteId = params.get("SiteId")
        self.MonitorId = params.get("MonitorId")
        if params.get("Filters") is not None:
            self.Filters = []
            for item in params.get("Filters"):
                obj = Filter()
                obj._deserialize(item)
                self.Filters.append(obj)
        self.Offset = params.get("Offset")
        self.Limit = params.get("Limit")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeVulsResponse(AbstractModel):
    """DescribeVuls返回参数结构体

    """

    def __init__(self):
        """
        :param TotalCount: 漏洞数量。\n        :type TotalCount: int\n        :param Vuls: 漏洞信息列表。\n        :type Vuls: list of Vul\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.TotalCount = None
        self.Vuls = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("Vuls") is not None:
            self.Vuls = []
            for item in params.get("Vuls"):
                obj = Vul()
                obj._deserialize(item)
                self.Vuls.append(obj)
        self.RequestId = params.get("RequestId")


class Filter(AbstractModel):
    """描述键值对过滤器，用于条件过滤查询。例如过滤ID、名称、状态等

    若存在多个Filter时，Filter间的关系为逻辑与（AND）关系。
    若同一个Filter存在多个Values，同一Filter下Values间的关系为逻辑或（OR）关系。

    """

    def __init__(self):
        """
        :param Name: 过滤键的名称。\n        :type Name: str\n        :param Values: 一个或者多个过滤值。\n        :type Values: list of str\n        """
        self.Name = None
        self.Values = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.Values = params.get("Values")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class MiniSite(AbstractModel):
    """站点信息。

    """

    def __init__(self):
        """
        :param SiteId: 站点ID。\n        :type SiteId: int\n        :param Url: 站点Url。\n        :type Url: str\n        """
        self.SiteId = None
        self.Url = None


    def _deserialize(self, params):
        self.SiteId = params.get("SiteId")
        self.Url = params.get("Url")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyConfigAttributeRequest(AbstractModel):
    """ModifyConfigAttribute请求参数结构体

    """

    def __init__(self):
        """
        :param NoticeLevel: 漏洞告警通知等级，4位分别代表：高危、中危、低危、提示\n        :type NoticeLevel: str\n        """
        self.NoticeLevel = None


    def _deserialize(self, params):
        self.NoticeLevel = params.get("NoticeLevel")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyConfigAttributeResponse(AbstractModel):
    """ModifyConfigAttribute返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class ModifyMonitorAttributeRequest(AbstractModel):
    """ModifyMonitorAttribute请求参数结构体

    """

    def __init__(self):
        """
        :param MonitorId: 监测任务ID\n        :type MonitorId: int\n        :param Urls: 站点的url列表\n        :type Urls: list of str\n        :param Name: 任务名称\n        :type Name: str\n        :param ScannerType: 扫描模式，normal-正常扫描；deep-深度扫描\n        :type ScannerType: str\n        :param Crontab: 扫描周期，单位小时，每X小时执行一次\n        :type Crontab: int\n        :param RateLimit: 扫描速率限制，每秒发送X个HTTP请求\n        :type RateLimit: int\n        :param FirstScanStartTime: 首次扫描开始时间\n        :type FirstScanStartTime: str\n        :param MonitorStatus: 监测状态：1-监测中；2-暂停监测\n        :type MonitorStatus: int\n        """
        self.MonitorId = None
        self.Urls = None
        self.Name = None
        self.ScannerType = None
        self.Crontab = None
        self.RateLimit = None
        self.FirstScanStartTime = None
        self.MonitorStatus = None


    def _deserialize(self, params):
        self.MonitorId = params.get("MonitorId")
        self.Urls = params.get("Urls")
        self.Name = params.get("Name")
        self.ScannerType = params.get("ScannerType")
        self.Crontab = params.get("Crontab")
        self.RateLimit = params.get("RateLimit")
        self.FirstScanStartTime = params.get("FirstScanStartTime")
        self.MonitorStatus = params.get("MonitorStatus")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyMonitorAttributeResponse(AbstractModel):
    """ModifyMonitorAttribute返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class ModifySiteAttributeRequest(AbstractModel):
    """ModifySiteAttribute请求参数结构体

    """

    def __init__(self):
        """
        :param SiteId: 站点ID\n        :type SiteId: int\n        :param Name: 站点名称\n        :type Name: str\n        :param NeedLogin: 网站是否需要登录扫描：0-未知；-1-不需要；1-需要\n        :type NeedLogin: int\n        :param LoginCookie: 登录后的cookie\n        :type LoginCookie: str\n        :param LoginCheckUrl: 用于测试cookie是否有效的URL\n        :type LoginCheckUrl: str\n        :param LoginCheckKw: 用于测试cookie是否有效的关键字\n        :type LoginCheckKw: str\n        :param ScanDisallow: 禁止扫描器扫描的目录关键字\n        :type ScanDisallow: str\n        """
        self.SiteId = None
        self.Name = None
        self.NeedLogin = None
        self.LoginCookie = None
        self.LoginCheckUrl = None
        self.LoginCheckKw = None
        self.ScanDisallow = None


    def _deserialize(self, params):
        self.SiteId = params.get("SiteId")
        self.Name = params.get("Name")
        self.NeedLogin = params.get("NeedLogin")
        self.LoginCookie = params.get("LoginCookie")
        self.LoginCheckUrl = params.get("LoginCheckUrl")
        self.LoginCheckKw = params.get("LoginCheckKw")
        self.ScanDisallow = params.get("ScanDisallow")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifySiteAttributeResponse(AbstractModel):
    """ModifySiteAttribute返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class Monitor(AbstractModel):
    """监控任务基础数据

    """

    def __init__(self):
        """
        :param Id: 监控任务ID。\n        :type Id: int\n        :param Name: 监控名称。\n        :type Name: str\n        :param MonitorStatus: 监测状态：1-监测中；2-暂停监测。\n        :type MonitorStatus: int\n        :param ScannerType: 监测模式，normal-正常扫描；deep-深度扫描。\n        :type ScannerType: str\n        :param Crontab: 扫描周期，单位小时，每X小时执行一次。\n        :type Crontab: int\n        :param IncludedVulsTypes: 指定扫描类型，3位数每位依次表示：扫描Web漏洞、扫描系统漏洞、扫描系统端口。\n        :type IncludedVulsTypes: str\n        :param RateLimit: 速率限制，每秒发送X个HTTP请求。\n        :type RateLimit: int\n        :param FirstScanStartTime: 首次扫描开始时间。\n        :type FirstScanStartTime: str\n        :param ScanStatus: 扫描状态：0-待扫描（无任何扫描结果）；1-扫描中（正在进行扫描）；2-已扫描（有扫描结果且不正在扫描）；3-扫描完成待同步结果。\n        :type ScanStatus: int\n        :param LastScanFinishTime: 上一次扫描完成时间。\n        :type LastScanFinishTime: str\n        :param CurrentScanStartTime: 当前扫描开始时间，如扫描完成则为上一次扫描的开始时间。\n        :type CurrentScanStartTime: str\n        :param CreatedAt: CreatedAt。\n        :type CreatedAt: str\n        :param UpdatedAt: UpdatedAt。\n        :type UpdatedAt: str\n        :param Appid: 云用户appid。\n        :type Appid: int\n        :param ContentScanStatus: 扫描状态：0-待检测；1-检测完成\n        :type ContentScanStatus: int\n        """
        self.Id = None
        self.Name = None
        self.MonitorStatus = None
        self.ScannerType = None
        self.Crontab = None
        self.IncludedVulsTypes = None
        self.RateLimit = None
        self.FirstScanStartTime = None
        self.ScanStatus = None
        self.LastScanFinishTime = None
        self.CurrentScanStartTime = None
        self.CreatedAt = None
        self.UpdatedAt = None
        self.Appid = None
        self.ContentScanStatus = None


    def _deserialize(self, params):
        self.Id = params.get("Id")
        self.Name = params.get("Name")
        self.MonitorStatus = params.get("MonitorStatus")
        self.ScannerType = params.get("ScannerType")
        self.Crontab = params.get("Crontab")
        self.IncludedVulsTypes = params.get("IncludedVulsTypes")
        self.RateLimit = params.get("RateLimit")
        self.FirstScanStartTime = params.get("FirstScanStartTime")
        self.ScanStatus = params.get("ScanStatus")
        self.LastScanFinishTime = params.get("LastScanFinishTime")
        self.CurrentScanStartTime = params.get("CurrentScanStartTime")
        self.CreatedAt = params.get("CreatedAt")
        self.UpdatedAt = params.get("UpdatedAt")
        self.Appid = params.get("Appid")
        self.ContentScanStatus = params.get("ContentScanStatus")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class MonitorMiniSite(AbstractModel):
    """监控任务中的站点信息。

    """

    def __init__(self):
        """
        :param SiteId: 站点ID。\n        :type SiteId: int\n        :param Url: 站点Url。\n        :type Url: str\n        """
        self.SiteId = None
        self.Url = None


    def _deserialize(self, params):
        self.SiteId = params.get("SiteId")
        self.Url = params.get("Url")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class MonitorsDetail(AbstractModel):
    """监控任务详细数据

    """

    def __init__(self):
        """
        :param Basic: 监控任务基础信息。\n        :type Basic: :class:`tencentcloud.cws.v20180312.models.Monitor`\n        :param Sites: 监控任务包含的站点列表。\n        :type Sites: list of MonitorMiniSite\n        :param SiteNumber: 监控任务包含的站点列表数量。\n        :type SiteNumber: int\n        :param ImpactSites: 监控任务包含的受漏洞威胁的站点列表。\n        :type ImpactSites: list of MonitorMiniSite\n        :param ImpactSiteNumber: 监控任务包含的受漏洞威胁的站点列表数量。\n        :type ImpactSiteNumber: int\n        :param VulsHighNumber: 高风险漏洞数量。\n        :type VulsHighNumber: int\n        :param VulsMiddleNumber: 中风险漏洞数量。\n        :type VulsMiddleNumber: int\n        :param VulsLowNumber: 低风险漏洞数量。\n        :type VulsLowNumber: int\n        :param VulsNoticeNumber: 提示数量。\n        :type VulsNoticeNumber: int\n        :param Progress: 监控任务包含的站点列表的平均扫描进度。\n        :type Progress: int\n        :param PageCount: 扫描页面总数。\n        :type PageCount: int\n        :param ContentNumber: 内容检测数量。\n        :type ContentNumber: int\n        """
        self.Basic = None
        self.Sites = None
        self.SiteNumber = None
        self.ImpactSites = None
        self.ImpactSiteNumber = None
        self.VulsHighNumber = None
        self.VulsMiddleNumber = None
        self.VulsLowNumber = None
        self.VulsNoticeNumber = None
        self.Progress = None
        self.PageCount = None
        self.ContentNumber = None


    def _deserialize(self, params):
        if params.get("Basic") is not None:
            self.Basic = Monitor()
            self.Basic._deserialize(params.get("Basic"))
        if params.get("Sites") is not None:
            self.Sites = []
            for item in params.get("Sites"):
                obj = MonitorMiniSite()
                obj._deserialize(item)
                self.Sites.append(obj)
        self.SiteNumber = params.get("SiteNumber")
        if params.get("ImpactSites") is not None:
            self.ImpactSites = []
            for item in params.get("ImpactSites"):
                obj = MonitorMiniSite()
                obj._deserialize(item)
                self.ImpactSites.append(obj)
        self.ImpactSiteNumber = params.get("ImpactSiteNumber")
        self.VulsHighNumber = params.get("VulsHighNumber")
        self.VulsMiddleNumber = params.get("VulsMiddleNumber")
        self.VulsLowNumber = params.get("VulsLowNumber")
        self.VulsNoticeNumber = params.get("VulsNoticeNumber")
        self.Progress = params.get("Progress")
        self.PageCount = params.get("PageCount")
        self.ContentNumber = params.get("ContentNumber")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class Site(AbstractModel):
    """站点数据

    """

    def __init__(self):
        """
        :param Id: 站点ID。\n        :type Id: int\n        :param MonitorId: 监控任务ID，为0时表示未加入监控任务。\n        :type MonitorId: int\n        :param Url: 站点url。\n        :type Url: str\n        :param Name: 站点名称。\n        :type Name: str\n        :param VerifyStatus: 验证状态：0-未验证；1-已验证；2-验证失效，待重新验证。\n        :type VerifyStatus: int\n        :param MonitorStatus: 监测状态：0-未监测；1-监测中；2-暂停监测。\n        :type MonitorStatus: int\n        :param ScanStatus: 扫描状态：0-待扫描（无任何扫描结果）；1-扫描中（正在进行扫描）；2-已扫描（有扫描结果且不正在扫描）；3-扫描完成待同步结果。\n        :type ScanStatus: int\n        :param LastScanTaskId: 最近一次的AIScanner的扫描任务id，注意取消的情况。\n        :type LastScanTaskId: int\n        :param LastScanStartTime: 最近一次扫描开始时间。\n        :type LastScanStartTime: str\n        :param LastScanFinishTime: 最近一次扫描完成时间。\n        :type LastScanFinishTime: str\n        :param LastScanCancelTime: 最近一次取消时间，取消即使用上一次扫描结果。\n        :type LastScanCancelTime: str\n        :param LastScanPageCount: 最近一次扫描扫描的页面数。\n        :type LastScanPageCount: int\n        :param LastScanScannerType: normal-正常扫描；deep-深度扫描。\n        :type LastScanScannerType: str\n        :param LastScanVulsHighNum: 最近一次扫描高风险漏洞数量。\n        :type LastScanVulsHighNum: int\n        :param LastScanVulsMiddleNum: 最近一次扫描中风险漏洞数量。\n        :type LastScanVulsMiddleNum: int\n        :param LastScanVulsLowNum: 最近一次扫描低风险漏洞数量。\n        :type LastScanVulsLowNum: int\n        :param LastScanVulsNoticeNum: 最近一次扫描提示信息数量。\n        :type LastScanVulsNoticeNum: int\n        :param CreatedAt: 记录添加时间。\n        :type CreatedAt: str\n        :param UpdatedAt: 记录最近修改时间。\n        :type UpdatedAt: str\n        :param LastScanRateLimit: 速率限制，每秒发送X个HTTP请求。\n        :type LastScanRateLimit: int\n        :param LastScanVulsNum: 最近一次扫描漏洞总数量。\n        :type LastScanVulsNum: int\n        :param LastScanNoticeNum: 最近一次扫描提示总数量\n        :type LastScanNoticeNum: int\n        :param Progress: 扫描进度，百分比整数\n        :type Progress: int\n        :param Appid: 云用户appid。\n        :type Appid: int\n        :param Uin: 云用户标识。\n        :type Uin: str\n        :param NeedLogin: 网站是否需要登录扫描：0-未知；-1-不需要；1-需要。\n        :type NeedLogin: int\n        :param LoginCookie: 登录后的cookie。\n        :type LoginCookie: str\n        :param LoginCookieValid: 登录后的cookie是否有效：0-无效；1-有效。\n        :type LoginCookieValid: int\n        :param LoginCheckUrl: 用于测试cookie是否有效的URL。\n        :type LoginCheckUrl: str\n        :param LoginCheckKw: 用于测试cookie是否有效的关键字。\n        :type LoginCheckKw: str\n        :param ScanDisallow: 禁止扫描器扫描的目录关键字。\n        :type ScanDisallow: str\n        :param UserAgent: 访问网站的客户端标识。\n        :type UserAgent: str\n        :param ContentStatus: 内容检测状态：0-未检测；1-已检测；\n        :type ContentStatus: int\n        :param LastScanContentNum: 最近一次扫描内容检测数量\n        :type LastScanContentNum: int\n        """
        self.Id = None
        self.MonitorId = None
        self.Url = None
        self.Name = None
        self.VerifyStatus = None
        self.MonitorStatus = None
        self.ScanStatus = None
        self.LastScanTaskId = None
        self.LastScanStartTime = None
        self.LastScanFinishTime = None
        self.LastScanCancelTime = None
        self.LastScanPageCount = None
        self.LastScanScannerType = None
        self.LastScanVulsHighNum = None
        self.LastScanVulsMiddleNum = None
        self.LastScanVulsLowNum = None
        self.LastScanVulsNoticeNum = None
        self.CreatedAt = None
        self.UpdatedAt = None
        self.LastScanRateLimit = None
        self.LastScanVulsNum = None
        self.LastScanNoticeNum = None
        self.Progress = None
        self.Appid = None
        self.Uin = None
        self.NeedLogin = None
        self.LoginCookie = None
        self.LoginCookieValid = None
        self.LoginCheckUrl = None
        self.LoginCheckKw = None
        self.ScanDisallow = None
        self.UserAgent = None
        self.ContentStatus = None
        self.LastScanContentNum = None


    def _deserialize(self, params):
        self.Id = params.get("Id")
        self.MonitorId = params.get("MonitorId")
        self.Url = params.get("Url")
        self.Name = params.get("Name")
        self.VerifyStatus = params.get("VerifyStatus")
        self.MonitorStatus = params.get("MonitorStatus")
        self.ScanStatus = params.get("ScanStatus")
        self.LastScanTaskId = params.get("LastScanTaskId")
        self.LastScanStartTime = params.get("LastScanStartTime")
        self.LastScanFinishTime = params.get("LastScanFinishTime")
        self.LastScanCancelTime = params.get("LastScanCancelTime")
        self.LastScanPageCount = params.get("LastScanPageCount")
        self.LastScanScannerType = params.get("LastScanScannerType")
        self.LastScanVulsHighNum = params.get("LastScanVulsHighNum")
        self.LastScanVulsMiddleNum = params.get("LastScanVulsMiddleNum")
        self.LastScanVulsLowNum = params.get("LastScanVulsLowNum")
        self.LastScanVulsNoticeNum = params.get("LastScanVulsNoticeNum")
        self.CreatedAt = params.get("CreatedAt")
        self.UpdatedAt = params.get("UpdatedAt")
        self.LastScanRateLimit = params.get("LastScanRateLimit")
        self.LastScanVulsNum = params.get("LastScanVulsNum")
        self.LastScanNoticeNum = params.get("LastScanNoticeNum")
        self.Progress = params.get("Progress")
        self.Appid = params.get("Appid")
        self.Uin = params.get("Uin")
        self.NeedLogin = params.get("NeedLogin")
        self.LoginCookie = params.get("LoginCookie")
        self.LoginCookieValid = params.get("LoginCookieValid")
        self.LoginCheckUrl = params.get("LoginCheckUrl")
        self.LoginCheckKw = params.get("LoginCheckKw")
        self.ScanDisallow = params.get("ScanDisallow")
        self.UserAgent = params.get("UserAgent")
        self.ContentStatus = params.get("ContentStatus")
        self.LastScanContentNum = params.get("LastScanContentNum")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class SitesVerification(AbstractModel):
    """站点验证数据

    """

    def __init__(self):
        """
        :param Domain: 根域名。\n        :type Domain: str\n        :param TxtName: txt解析域名验证的name。\n        :type TxtName: str\n        :param TxtText: txt解析域名验证的text。\n        :type TxtText: str\n        :param ValidTo: 验证有效期，在此之前有效。\n        :type ValidTo: str\n        :param VerifyStatus: 验证状态：0-未验证；1-已验证；2-验证失效，待重新验证。\n        :type VerifyStatus: int\n        :param CreatedAt: CreatedAt。\n        :type CreatedAt: str\n        :param UpdatedAt: UpdatedAt。\n        :type UpdatedAt: str\n        :param Id: ID。\n        :type Id: int\n        :param Appid: 云用户appid\n        :type Appid: int\n        :param VerifyUrl: 用于验证站点的url，即访问该url获取验证数据。\n        :type VerifyUrl: str\n        :param VerifyFileUrl: 获取验证验证文件的url。\n        :type VerifyFileUrl: str\n        """
        self.Domain = None
        self.TxtName = None
        self.TxtText = None
        self.ValidTo = None
        self.VerifyStatus = None
        self.CreatedAt = None
        self.UpdatedAt = None
        self.Id = None
        self.Appid = None
        self.VerifyUrl = None
        self.VerifyFileUrl = None


    def _deserialize(self, params):
        self.Domain = params.get("Domain")
        self.TxtName = params.get("TxtName")
        self.TxtText = params.get("TxtText")
        self.ValidTo = params.get("ValidTo")
        self.VerifyStatus = params.get("VerifyStatus")
        self.CreatedAt = params.get("CreatedAt")
        self.UpdatedAt = params.get("UpdatedAt")
        self.Id = params.get("Id")
        self.Appid = params.get("Appid")
        self.VerifyUrl = params.get("VerifyUrl")
        self.VerifyFileUrl = params.get("VerifyFileUrl")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class VerifySitesRequest(AbstractModel):
    """VerifySites请求参数结构体

    """

    def __init__(self):
        """
        :param Urls: 站点的url列表\n        :type Urls: list of str\n        """
        self.Urls = None


    def _deserialize(self, params):
        self.Urls = params.get("Urls")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class VerifySitesResponse(AbstractModel):
    """VerifySites返回参数结构体

    """

    def __init__(self):
        """
        :param SuccessNumber: 验证成功的根域名数量。\n        :type SuccessNumber: int\n        :param FailNumber: 验证失败的根域名数量。\n        :type FailNumber: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SuccessNumber = None
        self.FailNumber = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SuccessNumber = params.get("SuccessNumber")
        self.FailNumber = params.get("FailNumber")
        self.RequestId = params.get("RequestId")


class Vul(AbstractModel):
    """漏洞数据

    """

    def __init__(self):
        """
        :param Id: 漏洞ID。\n        :type Id: int\n        :param SiteId: 站点ID。\n        :type SiteId: int\n        :param TaskId: 扫描引擎的扫描任务ID。\n        :type TaskId: int\n        :param Level: 漏洞级别：high、middle、low、notice。\n        :type Level: str\n        :param Name: 漏洞名称。\n        :type Name: str\n        :param Url: 出现漏洞的url。\n        :type Url: str\n        :param Html: 网址/细节。\n        :type Html: str\n        :param Nickname: 漏洞类型。\n        :type Nickname: str\n        :param Harm: 危害说明。\n        :type Harm: str\n        :param Describe: 漏洞描述。\n        :type Describe: str\n        :param Solution: 解决方案。\n        :type Solution: str\n        :param From: 漏洞参考。\n        :type From: str\n        :param Parameter: 漏洞通过该参数攻击。\n        :type Parameter: str\n        :param CreatedAt: CreatedAt。\n        :type CreatedAt: str\n        :param UpdatedAt: UpdatedAt。\n        :type UpdatedAt: str\n        :param IsReported: 是否已经添加误报，0-否，1-是。\n        :type IsReported: int\n        :param Appid: 云用户appid。\n        :type Appid: int\n        :param Uin: 云用户标识。\n        :type Uin: str\n        """
        self.Id = None
        self.SiteId = None
        self.TaskId = None
        self.Level = None
        self.Name = None
        self.Url = None
        self.Html = None
        self.Nickname = None
        self.Harm = None
        self.Describe = None
        self.Solution = None
        self.From = None
        self.Parameter = None
        self.CreatedAt = None
        self.UpdatedAt = None
        self.IsReported = None
        self.Appid = None
        self.Uin = None


    def _deserialize(self, params):
        self.Id = params.get("Id")
        self.SiteId = params.get("SiteId")
        self.TaskId = params.get("TaskId")
        self.Level = params.get("Level")
        self.Name = params.get("Name")
        self.Url = params.get("Url")
        self.Html = params.get("Html")
        self.Nickname = params.get("Nickname")
        self.Harm = params.get("Harm")
        self.Describe = params.get("Describe")
        self.Solution = params.get("Solution")
        self.From = params.get("From")
        self.Parameter = params.get("Parameter")
        self.CreatedAt = params.get("CreatedAt")
        self.UpdatedAt = params.get("UpdatedAt")
        self.IsReported = params.get("IsReported")
        self.Appid = params.get("Appid")
        self.Uin = params.get("Uin")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class VulsTimeline(AbstractModel):
    """用户漏洞数随时间变化统计数据

    """

    def __init__(self):
        """
        :param Id: ID。\n        :type Id: int\n        :param Appid: 云用户appid。\n        :type Appid: int\n        :param Date: 日期。\n        :type Date: str\n        :param PageCount: 扫描页面总数量。\n        :type PageCount: int\n        :param SiteNum: 已验证网站总数量。\n        :type SiteNum: int\n        :param ImpactSiteNum: 受影响的网站总数量。\n        :type ImpactSiteNum: int\n        :param VulsHighNum: 高危漏洞总数量。\n        :type VulsHighNum: int\n        :param VulsMiddleNum: 中危漏洞总数量。\n        :type VulsMiddleNum: int\n        :param VulsLowNum: 低危漏洞总数量。\n        :type VulsLowNum: int\n        :param VulsNoticeNum: 风险提示总数量\n        :type VulsNoticeNum: int\n        :param CreatedAt: 记录添加时间。\n        :type CreatedAt: str\n        :param UpdatedAt: 记录最近修改时间。\n        :type UpdatedAt: str\n        """
        self.Id = None
        self.Appid = None
        self.Date = None
        self.PageCount = None
        self.SiteNum = None
        self.ImpactSiteNum = None
        self.VulsHighNum = None
        self.VulsMiddleNum = None
        self.VulsLowNum = None
        self.VulsNoticeNum = None
        self.CreatedAt = None
        self.UpdatedAt = None


    def _deserialize(self, params):
        self.Id = params.get("Id")
        self.Appid = params.get("Appid")
        self.Date = params.get("Date")
        self.PageCount = params.get("PageCount")
        self.SiteNum = params.get("SiteNum")
        self.ImpactSiteNum = params.get("ImpactSiteNum")
        self.VulsHighNum = params.get("VulsHighNum")
        self.VulsMiddleNum = params.get("VulsMiddleNum")
        self.VulsLowNum = params.get("VulsLowNum")
        self.VulsNoticeNum = params.get("VulsNoticeNum")
        self.CreatedAt = params.get("CreatedAt")
        self.UpdatedAt = params.get("UpdatedAt")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class DataManipulationRequest(AbstractModel):
    """DataManipulation请求参数结构体

    """

    def __init__(self):
        """
        :param OpType: 操作类型，add或del\n        :type OpType: str\n        :param Encoding: 数据编码类型\n        :type Encoding: str\n        :param Contents: 数据\n        :type Contents: str\n        :param ResourceId: 应用Id\n        :type ResourceId: int\n        """
        self.OpType = None
        self.Encoding = None
        self.Contents = None
        self.ResourceId = None


    def _deserialize(self, params):
        self.OpType = params.get("OpType")
        self.Encoding = params.get("Encoding")
        self.Contents = params.get("Contents")
        self.ResourceId = params.get("ResourceId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DataManipulationResponse(AbstractModel):
    """DataManipulation返回参数结构体

    """

    def __init__(self):
        """
        :param Data: 数据操作结果\n        :type Data: :class:`tencentcloud.yunsou.v20191115.models.DataManipulationResult`\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = DataManipulationResult()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class DataManipulationResult(AbstractModel):
    """数据操作结果

    """

    def __init__(self):
        """
        :param AppId: 应用ID\n        :type AppId: int\n        :param Seq: 序号\n        :type Seq: int\n        :param TotalResult: 结果\n        :type TotalResult: str\n        :param Result: 操作结果明细
注意：此字段可能返回 null，表示取不到有效值。\n        :type Result: list of DataManipulationResultItem\n        :param ErrorResult: 异常信息
注意：此字段可能返回 null，表示取不到有效值。\n        :type ErrorResult: str\n        """
        self.AppId = None
        self.Seq = None
        self.TotalResult = None
        self.Result = None
        self.ErrorResult = None


    def _deserialize(self, params):
        self.AppId = params.get("AppId")
        self.Seq = params.get("Seq")
        self.TotalResult = params.get("TotalResult")
        if params.get("Result") is not None:
            self.Result = []
            for item in params.get("Result"):
                obj = DataManipulationResultItem()
                obj._deserialize(item)
                self.Result.append(obj)
        self.ErrorResult = params.get("ErrorResult")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DataManipulationResultItem(AbstractModel):
    """数据操作结果明细

    """

    def __init__(self):
        """
        :param Result: 结果\n        :type Result: str\n        :param DocId: 文档ID\n        :type DocId: str\n        :param Errno: 错误码\n        :type Errno: int\n        """
        self.Result = None
        self.DocId = None
        self.Errno = None


    def _deserialize(self, params):
        self.Result = params.get("Result")
        self.DocId = params.get("DocId")
        self.Errno = params.get("Errno")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DataSearchRequest(AbstractModel):
    """DataSearch请求参数结构体

    """

    def __init__(self):
        """
        :param ResourceId: 云搜的业务ID，用以表明当前数据请求的业务\n        :type ResourceId: int\n        :param SearchQuery: 检索串\n        :type SearchQuery: str\n        :param PageId: 当前页，从第0页开始计算\n        :type PageId: int\n        :param NumPerPage: 每页结果数\n        :type NumPerPage: int\n        :param SearchId: 当前检索号，用于定位问题，建议指定并且全局唯一\n        :type SearchId: str\n        :param QueryEncode: 请求编码，0表示utf8，1表示gbk，建议指定\n        :type QueryEncode: int\n        :param RankType: 排序类型\n        :type RankType: int\n        :param NumFilter: 数值过滤，结果中按属性过滤\n        :type NumFilter: str\n        :param ClFilter: 分类过滤，导航类检索请求\n        :type ClFilter: str\n        :param Extra: 检索用户相关字段\n        :type Extra: str\n        :param SourceId: 检索来源\n        :type SourceId: int\n        :param SecondSearch: 是否进行二次检索，0关闭，1打开\n        :type SecondSearch: int\n        :param MaxDocReturn: 指定返回最大篇数，无特殊原因不建议指定\n        :type MaxDocReturn: int\n        :param IsSmartbox: 是否smartbox检索，0关闭，1打开\n        :type IsSmartbox: int\n        :param EnableAbsHighlight: 是否打开高红标亮，0关闭，1打开\n        :type EnableAbsHighlight: int\n        :param QcBid: 指定访问QC纠错业务ID\n        :type QcBid: int\n        :param GroupBy: 按指定字段进行group by，只能对数值字段进行操作\n        :type GroupBy: str\n        :param Distinct: 按指定字段进行distinct，只能对数值字段进行操作\n        :type Distinct: str\n        :param L4RankExpression: 高级排序参数，具体参见高级排序说明\n        :type L4RankExpression: str\n        :param MatchValue: 高级排序参数，具体参见高级排序说明\n        :type MatchValue: str\n        :param Longitude: 经度信息\n        :type Longitude: float\n        :param Latitude: 纬度信息\n        :type Latitude: float\n        :param MultiFilter: 分类过滤并集\n        :type MultiFilter: list of str\n        """
        self.ResourceId = None
        self.SearchQuery = None
        self.PageId = None
        self.NumPerPage = None
        self.SearchId = None
        self.QueryEncode = None
        self.RankType = None
        self.NumFilter = None
        self.ClFilter = None
        self.Extra = None
        self.SourceId = None
        self.SecondSearch = None
        self.MaxDocReturn = None
        self.IsSmartbox = None
        self.EnableAbsHighlight = None
        self.QcBid = None
        self.GroupBy = None
        self.Distinct = None
        self.L4RankExpression = None
        self.MatchValue = None
        self.Longitude = None
        self.Latitude = None
        self.MultiFilter = None


    def _deserialize(self, params):
        self.ResourceId = params.get("ResourceId")
        self.SearchQuery = params.get("SearchQuery")
        self.PageId = params.get("PageId")
        self.NumPerPage = params.get("NumPerPage")
        self.SearchId = params.get("SearchId")
        self.QueryEncode = params.get("QueryEncode")
        self.RankType = params.get("RankType")
        self.NumFilter = params.get("NumFilter")
        self.ClFilter = params.get("ClFilter")
        self.Extra = params.get("Extra")
        self.SourceId = params.get("SourceId")
        self.SecondSearch = params.get("SecondSearch")
        self.MaxDocReturn = params.get("MaxDocReturn")
        self.IsSmartbox = params.get("IsSmartbox")
        self.EnableAbsHighlight = params.get("EnableAbsHighlight")
        self.QcBid = params.get("QcBid")
        self.GroupBy = params.get("GroupBy")
        self.Distinct = params.get("Distinct")
        self.L4RankExpression = params.get("L4RankExpression")
        self.MatchValue = params.get("MatchValue")
        self.Longitude = params.get("Longitude")
        self.Latitude = params.get("Latitude")
        self.MultiFilter = params.get("MultiFilter")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DataSearchResponse(AbstractModel):
    """DataSearch返回参数结构体

    """

    def __init__(self):
        """
        :param Data: 检索结果\n        :type Data: :class:`tencentcloud.yunsou.v20191115.models.SearchResult`\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = SearchResult()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class SearchResult(AbstractModel):
    """搜索结果

    """

    def __init__(self):
        """
        :param CostTime: 检索耗时，单位ms\n        :type CostTime: int\n        :param DisplayNum: 搜索最多可以展示的结果数，多页\n        :type DisplayNum: int\n        :param Echo: 和检索请求中的echo相对应\n        :type Echo: str\n        :param EResultNum: 检索结果的估算篇数，由索引平台估算\n        :type EResultNum: int\n        :param ResultNum: 检索返回的当前页码结果数\n        :type ResultNum: int\n        :param ResultList: 检索结果列表
注意：此字段可能返回 null，表示取不到有效值。\n        :type ResultList: list of SearchResultItem\n        :param SegList: 检索的分词结果，array类型，可包含多个
注意：此字段可能返回 null，表示取不到有效值。\n        :type SegList: list of SearchResultSeg\n        """
        self.CostTime = None
        self.DisplayNum = None
        self.Echo = None
        self.EResultNum = None
        self.ResultNum = None
        self.ResultList = None
        self.SegList = None


    def _deserialize(self, params):
        self.CostTime = params.get("CostTime")
        self.DisplayNum = params.get("DisplayNum")
        self.Echo = params.get("Echo")
        self.EResultNum = params.get("EResultNum")
        self.ResultNum = params.get("ResultNum")
        if params.get("ResultList") is not None:
            self.ResultList = []
            for item in params.get("ResultList"):
                obj = SearchResultItem()
                obj._deserialize(item)
                self.ResultList.append(obj)
        if params.get("SegList") is not None:
            self.SegList = []
            for item in params.get("SegList"):
                obj = SearchResultSeg()
                obj._deserialize(item)
                self.SegList.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class SearchResultItem(AbstractModel):
    """搜索结果元素

    """

    def __init__(self):
        """
        :param DocAbs: 动态摘要信息\n        :type DocAbs: str\n        :param DocId: 检索文档id\n        :type DocId: str\n        :param DocMeta: 原始文档信息\n        :type DocMeta: str\n        :param L2Score: 精计算得分\n        :type L2Score: float\n        :param SearchDebuginfo: 文档级回传信息\n        :type SearchDebuginfo: str\n        """
        self.DocAbs = None
        self.DocId = None
        self.DocMeta = None
        self.L2Score = None
        self.SearchDebuginfo = None


    def _deserialize(self, params):
        self.DocAbs = params.get("DocAbs")
        self.DocId = params.get("DocId")
        self.DocMeta = params.get("DocMeta")
        self.L2Score = params.get("L2Score")
        self.SearchDebuginfo = params.get("SearchDebuginfo")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class SearchResultSeg(AbstractModel):
    """SearchResultSeg

    """

    def __init__(self):
        """
        :param SegStr: 分词\n        :type SegStr: str\n        """
        self.SegStr = None


    def _deserialize(self, params):
        self.SegStr = params.get("SegStr")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class CreateProductSecretRequest(AbstractModel):
    """CreateProductSecret请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 凭据名称，同一region内不可重复，最长128字节，使用字母、数字或者 - _ 的组合，第一个字符必须为字母或者数字。\n        :type SecretName: str\n        :param UserNamePrefix: 用户账号名前缀，由用户自行指定，长度限定在8个字符以内，
可选字符集包括：
数字字符：[0, 9]，
小写字符：[a, z]，
大写字符：[A, Z]，
特殊字符(全英文符号)：下划线(_)，
前缀必须以大写或小写字母开头。\n        :type UserNamePrefix: str\n        :param ProductName: 凭据所绑定的云产品名称，如Mysql，可以通过DescribeSupportedProducts接口获取所支持的云产品名称。\n        :type ProductName: str\n        :param InstanceID: 云产品实例ID。\n        :type InstanceID: str\n        :param Domains: 账号的域名，IP形式，支持填入%。\n        :type Domains: list of str\n        :param PrivilegesList: 将凭据与云产品实例绑定时，需要授予的权限列表。\n        :type PrivilegesList: list of ProductPrivilegeUnit\n        :param Description: 描述信息，用于详细描述用途等，最大支持2048字节。\n        :type Description: str\n        :param KmsKeyId: 指定对凭据进行加密的KMS CMK。
如果为空则表示使用Secrets Manager为您默认创建的CMK进行加密。
您也可以指定在同region 下自行创建的KMS CMK进行加密。\n        :type KmsKeyId: str\n        :param Tags: 标签列表。\n        :type Tags: list of Tag\n        :param RotationBeginTime: 用户自定义的开始轮转时间，格式：2006-01-02 15:04:05。
当EnableRotation为True时，此参数必填。\n        :type RotationBeginTime: str\n        :param EnableRotation: 是否开启轮转
True -- 开启
False -- 不开启
如果不指定，默认为False。\n        :type EnableRotation: bool\n        :param RotationFrequency: 轮转周期，以天为单位，默认为1天。\n        :type RotationFrequency: int\n        """
        self.SecretName = None
        self.UserNamePrefix = None
        self.ProductName = None
        self.InstanceID = None
        self.Domains = None
        self.PrivilegesList = None
        self.Description = None
        self.KmsKeyId = None
        self.Tags = None
        self.RotationBeginTime = None
        self.EnableRotation = None
        self.RotationFrequency = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.UserNamePrefix = params.get("UserNamePrefix")
        self.ProductName = params.get("ProductName")
        self.InstanceID = params.get("InstanceID")
        self.Domains = params.get("Domains")
        if params.get("PrivilegesList") is not None:
            self.PrivilegesList = []
            for item in params.get("PrivilegesList"):
                obj = ProductPrivilegeUnit()
                obj._deserialize(item)
                self.PrivilegesList.append(obj)
        self.Description = params.get("Description")
        self.KmsKeyId = params.get("KmsKeyId")
        if params.get("Tags") is not None:
            self.Tags = []
            for item in params.get("Tags"):
                obj = Tag()
                obj._deserialize(item)
                self.Tags.append(obj)
        self.RotationBeginTime = params.get("RotationBeginTime")
        self.EnableRotation = params.get("EnableRotation")
        self.RotationFrequency = params.get("RotationFrequency")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateProductSecretResponse(AbstractModel):
    """CreateProductSecret返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 创建的凭据名称。\n        :type SecretName: str\n        :param TagCode: 标签操作的返回码. 0: 成功；1: 内部错误；2: 业务处理错误。
注意：此字段可能返回 null，表示取不到有效值。
注意：此字段可能返回 null，表示取不到有效值。\n        :type TagCode: int\n        :param TagMsg: 标签操作的返回信息。
注意：此字段可能返回 null，表示取不到有效值。\n        :type TagMsg: str\n        :param FlowID: 创建云产品凭据异步任务ID号。\n        :type FlowID: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.TagCode = None
        self.TagMsg = None
        self.FlowID = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.TagCode = params.get("TagCode")
        self.TagMsg = params.get("TagMsg")
        self.FlowID = params.get("FlowID")
        self.RequestId = params.get("RequestId")


class CreateSecretRequest(AbstractModel):
    """CreateSecret请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 凭据名称，同一region内不可重复，最长128字节，使用字母、数字或者 - _ 的组合，第一个字符必须为字母或者数字。\n        :type SecretName: str\n        :param VersionId: 凭据版本，查询凭据信息时需要根据SecretName 和 VersionId进行查询，最长64 字节，使用字母、数字或者 - _ . 的组合并且以字母或数字开头。\n        :type VersionId: str\n        :param Description: 描述信息，用于详细描述用途等，最大支持2048字节。\n        :type Description: str\n        :param KmsKeyId: 指定对凭据进行加密的KMS CMK。如果为空则表示使用Secrets Manager为您默认创建的CMK进行加密。您也可以指定在同region 下自行创建的KMS CMK进行加密。\n        :type KmsKeyId: str\n        :param SecretBinary: 二进制凭据信息base64编码后的明文。SecretBinary 和 SecretString 必须且只能设置一个，最大支持4096字节。\n        :type SecretBinary: str\n        :param SecretString: 文本类型凭据信息明文（不需要进行base64编码）。SecretBinary 和 SecretString 必须且只能设置一个，，最大支持4096字节。\n        :type SecretString: str\n        :param Tags: 标签列表\n        :type Tags: list of Tag\n        """
        self.SecretName = None
        self.VersionId = None
        self.Description = None
        self.KmsKeyId = None
        self.SecretBinary = None
        self.SecretString = None
        self.Tags = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.VersionId = params.get("VersionId")
        self.Description = params.get("Description")
        self.KmsKeyId = params.get("KmsKeyId")
        self.SecretBinary = params.get("SecretBinary")
        self.SecretString = params.get("SecretString")
        if params.get("Tags") is not None:
            self.Tags = []
            for item in params.get("Tags"):
                obj = Tag()
                obj._deserialize(item)
                self.Tags.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateSecretResponse(AbstractModel):
    """CreateSecret返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 新创建的凭据名称。\n        :type SecretName: str\n        :param VersionId: 新创建的凭据版本。\n        :type VersionId: str\n        :param TagCode: 标签操作的返回码. 0: 成功；1: 内部错误；2: 业务处理错误
注意：此字段可能返回 null，表示取不到有效值。\n        :type TagCode: int\n        :param TagMsg: 标签操作的返回信息
注意：此字段可能返回 null，表示取不到有效值。\n        :type TagMsg: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.VersionId = None
        self.TagCode = None
        self.TagMsg = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.VersionId = params.get("VersionId")
        self.TagCode = params.get("TagCode")
        self.TagMsg = params.get("TagMsg")
        self.RequestId = params.get("RequestId")


class DeleteSecretRequest(AbstractModel):
    """DeleteSecret请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定需要删除的凭据名称。\n        :type SecretName: str\n        :param RecoveryWindowInDays: 指定计划删除日期，单位（天），0（默认）表示立即删除， 1-30 表示预留的天数，超出该日期之后彻底删除。\n        :type RecoveryWindowInDays: int\n        """
        self.SecretName = None
        self.RecoveryWindowInDays = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.RecoveryWindowInDays = params.get("RecoveryWindowInDays")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DeleteSecretResponse(AbstractModel):
    """DeleteSecret返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定删除的凭据名称。\n        :type SecretName: str\n        :param DeleteTime: 凭据删除的日期，unix时间戳。\n        :type DeleteTime: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.DeleteTime = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.DeleteTime = params.get("DeleteTime")
        self.RequestId = params.get("RequestId")


class DeleteSecretVersionRequest(AbstractModel):
    """DeleteSecretVersion请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定凭据名称。\n        :type SecretName: str\n        :param VersionId: 指定该名称下需要删除的凭据的版本号。\n        :type VersionId: str\n        """
        self.SecretName = None
        self.VersionId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.VersionId = params.get("VersionId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DeleteSecretVersionResponse(AbstractModel):
    """DeleteSecretVersion返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param VersionId: 凭据版本号。\n        :type VersionId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.VersionId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.VersionId = params.get("VersionId")
        self.RequestId = params.get("RequestId")


class DescribeAsyncRequestInfoRequest(AbstractModel):
    """DescribeAsyncRequestInfo请求参数结构体

    """

    def __init__(self):
        """
        :param FlowID: 异步任务ID号。\n        :type FlowID: int\n        """
        self.FlowID = None


    def _deserialize(self, params):
        self.FlowID = params.get("FlowID")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeAsyncRequestInfoResponse(AbstractModel):
    """DescribeAsyncRequestInfo返回参数结构体

    """

    def __init__(self):
        """
        :param TaskStatus: 0:处理中，1:处理成功，2:处理失败\n        :type TaskStatus: int\n        :param Description: 任务描述信息。\n        :type Description: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.TaskStatus = None
        self.Description = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TaskStatus = params.get("TaskStatus")
        self.Description = params.get("Description")
        self.RequestId = params.get("RequestId")


class DescribeRotationDetailRequest(AbstractModel):
    """DescribeRotationDetail请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定需要获取凭据轮转详细信息的凭据名称。\n        :type SecretName: str\n        """
        self.SecretName = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeRotationDetailResponse(AbstractModel):
    """DescribeRotationDetail返回参数结构体

    """

    def __init__(self):
        """
        :param EnableRotation: 否允许轮转，True表示开启轮转，False表示禁止轮转。\n        :type EnableRotation: bool\n        :param Frequency: 轮转的频率，以天为单位，默认为1天。
注意：此字段可能返回 null，表示取不到有效值。\n        :type Frequency: int\n        :param LatestRotateTime: 最近一次轮转的时间，显式可见的时间字符串，格式 2006-01-02 15:04:05。
注意：此字段可能返回 null，表示取不到有效值。\n        :type LatestRotateTime: str\n        :param NextRotateBeginTime: 下一次开始轮转的时间，显式可见的时间字符串，格式 2006-01-02 15:04:05。
注意：此字段可能返回 null，表示取不到有效值。\n        :type NextRotateBeginTime: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.EnableRotation = None
        self.Frequency = None
        self.LatestRotateTime = None
        self.NextRotateBeginTime = None
        self.RequestId = None


    def _deserialize(self, params):
        self.EnableRotation = params.get("EnableRotation")
        self.Frequency = params.get("Frequency")
        self.LatestRotateTime = params.get("LatestRotateTime")
        self.NextRotateBeginTime = params.get("NextRotateBeginTime")
        self.RequestId = params.get("RequestId")


class DescribeRotationHistoryRequest(AbstractModel):
    """DescribeRotationHistory请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定需要获取凭据轮转历史的凭据名称。\n        :type SecretName: str\n        """
        self.SecretName = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeRotationHistoryResponse(AbstractModel):
    """DescribeRotationHistory返回参数结构体

    """

    def __init__(self):
        """
        :param VersionIDs: 版本号列表。\n        :type VersionIDs: list of str\n        :param TotalCount: 版本号个数，可以给用户展示的版本号个数上限为10个。\n        :type TotalCount: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.VersionIDs = None
        self.TotalCount = None
        self.RequestId = None


    def _deserialize(self, params):
        self.VersionIDs = params.get("VersionIDs")
        self.TotalCount = params.get("TotalCount")
        self.RequestId = params.get("RequestId")


class DescribeSecretRequest(AbstractModel):
    """DescribeSecret请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定需要获取凭据详细信息的凭据名称。\n        :type SecretName: str\n        """
        self.SecretName = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeSecretResponse(AbstractModel):
    """DescribeSecret返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param Description: 凭据描述信息。\n        :type Description: str\n        :param KmsKeyId: 用于加密的KMS CMK ID。\n        :type KmsKeyId: str\n        :param CreateUin: 创建者UIN。\n        :type CreateUin: int\n        :param Status: 凭据状态：Enabled、Disabled、PendingDelete, Creating, Failed。\n        :type Status: str\n        :param DeleteTime: 删除日期，uinx 时间戳，非计划删除状态的凭据为0。\n        :type DeleteTime: int\n        :param CreateTime: 创建日期。\n        :type CreateTime: int\n        :param SecretType: 0 --  用户自定义凭据类型；1 -- 云产品凭据类型。
注意：此字段可能返回 null，表示取不到有效值。\n        :type SecretType: int\n        :param ProductName: 云产品名称。
注意：此字段可能返回 null，表示取不到有效值。\n        :type ProductName: str\n        :param ResourceID: 云产品实例ID。
注意：此字段可能返回 null，表示取不到有效值。\n        :type ResourceID: str\n        :param RotationStatus: 是否开启轮转：True -- 开启轮转；False -- 禁止轮转。
注意：此字段可能返回 null，表示取不到有效值。\n        :type RotationStatus: bool\n        :param RotationFrequency: 轮转周期，默认以天为单位。
注意：此字段可能返回 null，表示取不到有效值。\n        :type RotationFrequency: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.Description = None
        self.KmsKeyId = None
        self.CreateUin = None
        self.Status = None
        self.DeleteTime = None
        self.CreateTime = None
        self.SecretType = None
        self.ProductName = None
        self.ResourceID = None
        self.RotationStatus = None
        self.RotationFrequency = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.Description = params.get("Description")
        self.KmsKeyId = params.get("KmsKeyId")
        self.CreateUin = params.get("CreateUin")
        self.Status = params.get("Status")
        self.DeleteTime = params.get("DeleteTime")
        self.CreateTime = params.get("CreateTime")
        self.SecretType = params.get("SecretType")
        self.ProductName = params.get("ProductName")
        self.ResourceID = params.get("ResourceID")
        self.RotationStatus = params.get("RotationStatus")
        self.RotationFrequency = params.get("RotationFrequency")
        self.RequestId = params.get("RequestId")


class DescribeSupportedProductsRequest(AbstractModel):
    """DescribeSupportedProducts请求参数结构体

    """


class DescribeSupportedProductsResponse(AbstractModel):
    """DescribeSupportedProducts返回参数结构体

    """

    def __init__(self):
        """
        :param Products: 支持的产品列表。\n        :type Products: list of str\n        :param TotalCount: 支持的产品个数\n        :type TotalCount: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Products = None
        self.TotalCount = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Products = params.get("Products")
        self.TotalCount = params.get("TotalCount")
        self.RequestId = params.get("RequestId")


class DisableSecretRequest(AbstractModel):
    """DisableSecret请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定停用的凭据名称。\n        :type SecretName: str\n        """
        self.SecretName = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DisableSecretResponse(AbstractModel):
    """DisableSecret返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 停用的凭据名称。\n        :type SecretName: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.RequestId = params.get("RequestId")


class EnableSecretRequest(AbstractModel):
    """EnableSecret请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定启用凭据的名称。\n        :type SecretName: str\n        """
        self.SecretName = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class EnableSecretResponse(AbstractModel):
    """EnableSecret返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 启用的凭据名称。\n        :type SecretName: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.RequestId = params.get("RequestId")


class GetRegionsRequest(AbstractModel):
    """GetRegions请求参数结构体

    """


class GetRegionsResponse(AbstractModel):
    """GetRegions返回参数结构体

    """

    def __init__(self):
        """
        :param Regions: region列表。\n        :type Regions: list of str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Regions = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Regions = params.get("Regions")
        self.RequestId = params.get("RequestId")


class GetSecretValueRequest(AbstractModel):
    """GetSecretValue请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定凭据的名称。\n        :type SecretName: str\n        :param VersionId: 指定对应凭据的版本号。
对于云产品凭据如Mysql凭据，通过指定凭据名称和历史版本号来获取历史轮转凭据的明文信息，如果要获取当前正在使用的凭据版本的明文，需要将版本号指定为：SSM_Current。\n        :type VersionId: str\n        """
        self.SecretName = None
        self.VersionId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.VersionId = params.get("VersionId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetSecretValueResponse(AbstractModel):
    """GetSecretValue返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 凭据的名称。\n        :type SecretName: str\n        :param VersionId: 该凭据对应的版本号。\n        :type VersionId: str\n        :param SecretBinary: 在创建凭据(CreateSecret)时，如果指定的是二进制数据，则该字段为返回结果，并且使用base64进行编码，应用方需要进行base64解码后获取原始数据。
SecretBinary和SecretString只有一个不为空。\n        :type SecretBinary: str\n        :param SecretString: 在创建凭据(CreateSecret)时，如果指定的是普通文本数据，则该字段为返回结果。
SecretBinary和SecretString只有一个不为空。\n        :type SecretString: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.VersionId = None
        self.SecretBinary = None
        self.SecretString = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.VersionId = params.get("VersionId")
        self.SecretBinary = params.get("SecretBinary")
        self.SecretString = params.get("SecretString")
        self.RequestId = params.get("RequestId")


class GetServiceStatusRequest(AbstractModel):
    """GetServiceStatus请求参数结构体

    """


class GetServiceStatusResponse(AbstractModel):
    """GetServiceStatus返回参数结构体

    """

    def __init__(self):
        """
        :param ServiceEnabled: true表示服务已开通，false 表示服务尚未开通。\n        :type ServiceEnabled: bool\n        :param InvalidType: 服务不可用类型： 0-未购买，1-正常， 2-欠费停服， 3-资源释放。\n        :type InvalidType: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.ServiceEnabled = None
        self.InvalidType = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ServiceEnabled = params.get("ServiceEnabled")
        self.InvalidType = params.get("InvalidType")
        self.RequestId = params.get("RequestId")


class ListSecretVersionIdsRequest(AbstractModel):
    """ListSecretVersionIds请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 凭据名称。\n        :type SecretName: str\n        """
        self.SecretName = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ListSecretVersionIdsResponse(AbstractModel):
    """ListSecretVersionIds返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param Versions: VersionId列表。
注意：此字段可能返回 null，表示取不到有效值。\n        :type Versions: list of VersionInfo\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.Versions = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        if params.get("Versions") is not None:
            self.Versions = []
            for item in params.get("Versions"):
                obj = VersionInfo()
                obj._deserialize(item)
                self.Versions.append(obj)
        self.RequestId = params.get("RequestId")


class ListSecretsRequest(AbstractModel):
    """ListSecrets请求参数结构体

    """

    def __init__(self):
        """
        :param Offset: 查询列表的起始位置，以0开始，不设置默认为0。\n        :type Offset: int\n        :param Limit: 单次查询返回的最大数量，0或不设置则使用默认值 20。\n        :type Limit: int\n        :param OrderType: 根据创建时间的排序方式，0或者不设置则使用降序排序， 1 表示升序排序。\n        :type OrderType: int\n        :param State: 根据凭据状态进行过滤。
默认为0表示查询全部。
1 --  表示查询Enabled 凭据列表。
2 --  表示查询Disabled 凭据列表。
3 --  表示查询PendingDelete 凭据列表。
4 --  表示PendingCreate。
5 --  表示CreateFailed。
其中状态PendingCreate和CreateFailed只有在SecretType为云产品凭据时生效\n        :type State: int\n        :param SearchSecretName: 根据凭据名称进行过滤，为空表示不过滤。\n        :type SearchSecretName: str\n        :param TagFilters: 标签过滤条件。\n        :type TagFilters: list of TagFilter\n        :param SecretType: 0  -- 表示用户自定义凭据，默认为0。
1  -- 表示用户云产品凭据。
这个参数只能在云产品凭据(1)和用户自定义凭据(0)中二选一。\n        :type SecretType: int\n        """
        self.Offset = None
        self.Limit = None
        self.OrderType = None
        self.State = None
        self.SearchSecretName = None
        self.TagFilters = None
        self.SecretType = None


    def _deserialize(self, params):
        self.Offset = params.get("Offset")
        self.Limit = params.get("Limit")
        self.OrderType = params.get("OrderType")
        self.State = params.get("State")
        self.SearchSecretName = params.get("SearchSecretName")
        if params.get("TagFilters") is not None:
            self.TagFilters = []
            for item in params.get("TagFilters"):
                obj = TagFilter()
                obj._deserialize(item)
                self.TagFilters.append(obj)
        self.SecretType = params.get("SecretType")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ListSecretsResponse(AbstractModel):
    """ListSecrets返回参数结构体

    """

    def __init__(self):
        """
        :param TotalCount: 根据State和SearchSecretName 筛选的凭据总数。\n        :type TotalCount: int\n        :param SecretMetadatas: 返回凭据信息列表。\n        :type SecretMetadatas: list of SecretMetadata\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.TotalCount = None
        self.SecretMetadatas = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("SecretMetadatas") is not None:
            self.SecretMetadatas = []
            for item in params.get("SecretMetadatas"):
                obj = SecretMetadata()
                obj._deserialize(item)
                self.SecretMetadatas.append(obj)
        self.RequestId = params.get("RequestId")


class ProductPrivilegeUnit(AbstractModel):
    """凭据关联产品时被赋予的权限

    """

    def __init__(self):
        """
        :param PrivilegeName: 权限名称，当前可选：
GlobalPrivileges
DatabasePrivileges
TablePrivileges
ColumnPrivileges

当权限为DatabasePrivileges时，必须通过参数Database指定数据库名；

当权限为TablePrivileges时，必须通过参数Database和TableName指定数据库名以及数据库中的表名；

当权限为ColumnPrivileges时，必须通过参数Database、TableName和CoulmnName指定数据库、数据库中的表名以及表中的列名。\n        :type PrivilegeName: str\n        :param Privileges: 权限列表。
对于Mysql产品来说，可选权限值为：

1. GlobalPrivileges 中权限的可选值为："SELECT","INSERT","UPDATE","DELETE","CREATE", "PROCESS", "DROP","REFERENCES","INDEX","ALTER","SHOW DATABASES","CREATE TEMPORARY TABLES","LOCK TABLES","EXECUTE","CREATE VIEW","SHOW VIEW","CREATE ROUTINE","ALTER ROUTINE","EVENT","TRIGGER"。
注意，不传该参数表示清除该权限。

2. DatabasePrivileges 权限的可选值为："SELECT","INSERT","UPDATE","DELETE","CREATE", "DROP","REFERENCES","INDEX","ALTER","CREATE TEMPORARY TABLES","LOCK TABLES","EXECUTE","CREATE VIEW","SHOW VIEW","CREATE ROUTINE","ALTER ROUTINE","EVENT","TRIGGER"。
注意，不传该参数表示清除该权限。

3. TablePrivileges 权限的可选值为：权限的可选值为："SELECT","INSERT","UPDATE","DELETE","CREATE", "DROP","REFERENCES","INDEX","ALTER","CREATE VIEW","SHOW VIEW", "TRIGGER"。
注意，不传该参数表示清除该权限。

4. ColumnPrivileges 权限的可选值为："SELECT","INSERT","UPDATE","REFERENCES"。
注意，不传该参数表示清除该权限。\n        :type Privileges: list of str\n        :param Database: 仅当PrivilegeName为DatabasePrivileges时这个值才有效。\n        :type Database: str\n        :param TableName: 仅当PrivilegeName为TablePrivileges时这个值才有效，并且此时需要填充Database显式指明所在的数据库实例。\n        :type TableName: str\n        :param ColumnName: 仅当PrivilegeName为ColumnPrivileges时这个值才生效，并且此时必须填充：
Database - 显式指明所在的数据库实例。
TableName - 显式指明所在表\n        :type ColumnName: str\n        """
        self.PrivilegeName = None
        self.Privileges = None
        self.Database = None
        self.TableName = None
        self.ColumnName = None


    def _deserialize(self, params):
        self.PrivilegeName = params.get("PrivilegeName")
        self.Privileges = params.get("Privileges")
        self.Database = params.get("Database")
        self.TableName = params.get("TableName")
        self.ColumnName = params.get("ColumnName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class PutSecretValueRequest(AbstractModel):
    """PutSecretValue请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定需要增加版本的凭据名称。\n        :type SecretName: str\n        :param VersionId: 指定新增加的版本号，最长64 字节，使用字母、数字或者 - _ . 的组合并且以字母或数字开头。\n        :type VersionId: str\n        :param SecretBinary: 二进制凭据信息，使用base64编码。
SecretBinary 和 SecretString 必须且只能设置一个。\n        :type SecretBinary: str\n        :param SecretString: 文本类型凭据信息明文（不需要进行base64编码），SecretBinary 和 SecretString 必须且只能设置一个。\n        :type SecretString: str\n        """
        self.SecretName = None
        self.VersionId = None
        self.SecretBinary = None
        self.SecretString = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.VersionId = params.get("VersionId")
        self.SecretBinary = params.get("SecretBinary")
        self.SecretString = params.get("SecretString")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class PutSecretValueResponse(AbstractModel):
    """PutSecretValue返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param VersionId: 新增加的版本号。\n        :type VersionId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.VersionId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.VersionId = params.get("VersionId")
        self.RequestId = params.get("RequestId")


class RestoreSecretRequest(AbstractModel):
    """RestoreSecret请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定需要恢复的凭据名称。\n        :type SecretName: str\n        """
        self.SecretName = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class RestoreSecretResponse(AbstractModel):
    """RestoreSecret返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.RequestId = params.get("RequestId")


class RotateProductSecretRequest(AbstractModel):
    """RotateProductSecret请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 需要轮转的凭据名。\n        :type SecretName: str\n        """
        self.SecretName = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class RotateProductSecretResponse(AbstractModel):
    """RotateProductSecret返回参数结构体

    """

    def __init__(self):
        """
        :param FlowID: 轮转异步任务ID号。\n        :type FlowID: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.FlowID = None
        self.RequestId = None


    def _deserialize(self, params):
        self.FlowID = params.get("FlowID")
        self.RequestId = params.get("RequestId")


class SecretMetadata(AbstractModel):
    """凭据的基础信息

    """

    def __init__(self):
        """
        :param SecretName: 凭据名称\n        :type SecretName: str\n        :param Description: 凭据的描述信息\n        :type Description: str\n        :param KmsKeyId: 用于加密凭据的KMS KeyId\n        :type KmsKeyId: str\n        :param CreateUin: 创建者UIN\n        :type CreateUin: int\n        :param Status: 凭据状态：Enabled、Disabled、PendingDelete、Creating、Failed\n        :type Status: str\n        :param DeleteTime: 凭据删除日期，对于status为PendingDelete 的有效，unix时间戳\n        :type DeleteTime: int\n        :param CreateTime: 凭据创建时间，unix时间戳\n        :type CreateTime: int\n        :param KmsKeyType: 用于加密凭据的KMS CMK类型，DEFAULT 表示SecretsManager 创建的默认密钥， CUSTOMER 表示用户指定的密钥\n        :type KmsKeyType: str\n        :param RotationStatus: 1:--开启轮转；0--禁止轮转
注意：此字段可能返回 null，表示取不到有效值。\n        :type RotationStatus: int\n        :param NextRotationTime: 下一次轮转开始时间，uinx 时间戳
注意：此字段可能返回 null，表示取不到有效值。\n        :type NextRotationTime: int\n        :param SecretType: 0 -- 用户自定义凭据；1 -- 云产品凭据
注意：此字段可能返回 null，表示取不到有效值。\n        :type SecretType: int\n        :param ProductName: 云产品名称，仅在SecretType为1，即凭据类型为云产品凭据时生效
注意：此字段可能返回 null，表示取不到有效值。\n        :type ProductName: str\n        """
        self.SecretName = None
        self.Description = None
        self.KmsKeyId = None
        self.CreateUin = None
        self.Status = None
        self.DeleteTime = None
        self.CreateTime = None
        self.KmsKeyType = None
        self.RotationStatus = None
        self.NextRotationTime = None
        self.SecretType = None
        self.ProductName = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.Description = params.get("Description")
        self.KmsKeyId = params.get("KmsKeyId")
        self.CreateUin = params.get("CreateUin")
        self.Status = params.get("Status")
        self.DeleteTime = params.get("DeleteTime")
        self.CreateTime = params.get("CreateTime")
        self.KmsKeyType = params.get("KmsKeyType")
        self.RotationStatus = params.get("RotationStatus")
        self.NextRotationTime = params.get("NextRotationTime")
        self.SecretType = params.get("SecretType")
        self.ProductName = params.get("ProductName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class Tag(AbstractModel):
    """标签键和标签值

    """

    def __init__(self):
        """
        :param TagKey: 标签键\n        :type TagKey: str\n        :param TagValue: 标签值\n        :type TagValue: str\n        """
        self.TagKey = None
        self.TagValue = None


    def _deserialize(self, params):
        self.TagKey = params.get("TagKey")
        self.TagValue = params.get("TagValue")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TagFilter(AbstractModel):
    """标签过滤器

    """

    def __init__(self):
        """
        :param TagKey: 标签键\n        :type TagKey: str\n        :param TagValue: 标签值\n        :type TagValue: list of str\n        """
        self.TagKey = None
        self.TagValue = None


    def _deserialize(self, params):
        self.TagKey = params.get("TagKey")
        self.TagValue = params.get("TagValue")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class UpdateDescriptionRequest(AbstractModel):
    """UpdateDescription请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定需要更新描述信息的凭据名。\n        :type SecretName: str\n        :param Description: 新的描述信息，最大长度2048个字节。\n        :type Description: str\n        """
        self.SecretName = None
        self.Description = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.Description = params.get("Description")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class UpdateDescriptionResponse(AbstractModel):
    """UpdateDescription返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.RequestId = params.get("RequestId")


class UpdateRotationStatusRequest(AbstractModel):
    """UpdateRotationStatus请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 云产品凭据名称。\n        :type SecretName: str\n        :param EnableRotation: 是否开启轮转。
True -- 开启轮转；
False -- 禁止轮转。\n        :type EnableRotation: bool\n        :param Frequency: 轮转周期，以天为单位，最小为30天，最大为365天。\n        :type Frequency: int\n        :param RotationBeginTime: 用户设置的期望开始轮转时间，格式为：2006-01-02 15:04:05。
当EnableRotation为True时，如果不填RotationBeginTime，则默认填充为当前时间。\n        :type RotationBeginTime: str\n        """
        self.SecretName = None
        self.EnableRotation = None
        self.Frequency = None
        self.RotationBeginTime = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.EnableRotation = params.get("EnableRotation")
        self.Frequency = params.get("Frequency")
        self.RotationBeginTime = params.get("RotationBeginTime")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class UpdateRotationStatusResponse(AbstractModel):
    """UpdateRotationStatus返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class UpdateSecretRequest(AbstractModel):
    """UpdateSecret请求参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 指定需要更新凭据内容的名称。\n        :type SecretName: str\n        :param VersionId: 指定需要更新凭据内容的版本号。\n        :type VersionId: str\n        :param SecretBinary: 新的凭据内容为二进制的场景使用该字段，并使用base64进行编码。
SecretBinary 和 SecretString 只能一个不为空。\n        :type SecretBinary: str\n        :param SecretString: 新的凭据内容为文本的场景使用该字段，不需要base64编码SecretBinary 和 SecretString 只能一个不为空。\n        :type SecretString: str\n        """
        self.SecretName = None
        self.VersionId = None
        self.SecretBinary = None
        self.SecretString = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.VersionId = params.get("VersionId")
        self.SecretBinary = params.get("SecretBinary")
        self.SecretString = params.get("SecretString")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class UpdateSecretResponse(AbstractModel):
    """UpdateSecret返回参数结构体

    """

    def __init__(self):
        """
        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param VersionId: 凭据版本号。\n        :type VersionId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.SecretName = None
        self.VersionId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SecretName = params.get("SecretName")
        self.VersionId = params.get("VersionId")
        self.RequestId = params.get("RequestId")


class VersionInfo(AbstractModel):
    """凭据版本号列表信息

    """

    def __init__(self):
        """
        :param VersionId: 版本号。\n        :type VersionId: str\n        :param CreateTime: 创建时间，unix时间戳。\n        :type CreateTime: int\n        """
        self.VersionId = None
        self.CreateTime = None


    def _deserialize(self, params):
        self.VersionId = params.get("VersionId")
        self.CreateTime = params.get("CreateTime")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class CompareMetricsData(AbstractModel):
    """结构化对比指标（准确率/召回率）数据

    """

    def __init__(self):
        """
        :param ShortStructAccuracy: 短文准确率
注意：此字段可能返回 null，表示取不到有效值。\n        :type ShortStructAccuracy: str\n        :param ShortStructRecall: 短文召回率
注意：此字段可能返回 null，表示取不到有效值。\n        :type ShortStructRecall: str\n        :param LongStructAccuracy: 长文结构化准确率
注意：此字段可能返回 null，表示取不到有效值。\n        :type LongStructAccuracy: str\n        :param LongStructRecall: 长文结构化召回率
注意：此字段可能返回 null，表示取不到有效值。\n        :type LongStructRecall: str\n        :param LongContentAccuracy: 长文提取准确率
注意：此字段可能返回 null，表示取不到有效值。\n        :type LongContentAccuracy: str\n        :param LongContentRecall: 长文提取召回率
注意：此字段可能返回 null，表示取不到有效值。\n        :type LongContentRecall: str\n        """
        self.ShortStructAccuracy = None
        self.ShortStructRecall = None
        self.LongStructAccuracy = None
        self.LongStructRecall = None
        self.LongContentAccuracy = None
        self.LongContentRecall = None


    def _deserialize(self, params):
        self.ShortStructAccuracy = params.get("ShortStructAccuracy")
        self.ShortStructRecall = params.get("ShortStructRecall")
        self.LongStructAccuracy = params.get("LongStructAccuracy")
        self.LongStructRecall = params.get("LongStructRecall")
        self.LongContentAccuracy = params.get("LongContentAccuracy")
        self.LongContentRecall = params.get("LongContentRecall")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateStructureTaskInfo(AbstractModel):
    """创建结构化任务子任务信息

    """

    def __init__(self):
        """
        :param TaskType: 任务类型\n        :type TaskType: str\n        :param FileList: 报告文件上传的地址列表，需按顺序排列。如果使用ImageList参数，置为空数组即可\n        :type FileList: list of str\n        :param CustomerId: 客户号\n        :type CustomerId: str\n        :param CustomerName: 客户姓名\n        :type CustomerName: str\n        :param ImageList: 报告上传的图片内容数组，图片内容采用base64编码，需按顺序排列\n        :type ImageList: list of str\n        :param Year: 报告年份\n        :type Year: str\n        """
        self.TaskType = None
        self.FileList = None
        self.CustomerId = None
        self.CustomerName = None
        self.ImageList = None
        self.Year = None


    def _deserialize(self, params):
        self.TaskType = params.get("TaskType")
        self.FileList = params.get("FileList")
        self.CustomerId = params.get("CustomerId")
        self.CustomerName = params.get("CustomerName")
        self.ImageList = params.get("ImageList")
        self.Year = params.get("Year")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateStructureTaskRequest(AbstractModel):
    """CreateStructureTask请求参数结构体

    """

    def __init__(self):
        """
        :param ServiceType: 服务类型
Structured 仅结构化
Underwrite 结构化+核保\n        :type ServiceType: str\n        :param TaskInfos: 创建任务时可以上传多个报告，后台生成多个识别子任务，子任务的详细信息\n        :type TaskInfos: list of CreateStructureTaskInfo\n        :param PolicyId: 保单号\n        :type PolicyId: str\n        :param TriggerType: 核保触发方式
Auto 自动
Manual 手动\n        :type TriggerType: str\n        :param InsuranceTypes: 险种，如果是体检报告类型，此参数是必填，类型说明如下：
CriticalDiseaseInsurance:重疾险
LifeInsurance：寿险
AccidentInsurance：意外险\n        :type InsuranceTypes: list of str\n        :param CallbackUrl: 回调地址，接收Post请求传送结果\n        :type CallbackUrl: str\n        """
        self.ServiceType = None
        self.TaskInfos = None
        self.PolicyId = None
        self.TriggerType = None
        self.InsuranceTypes = None
        self.CallbackUrl = None


    def _deserialize(self, params):
        self.ServiceType = params.get("ServiceType")
        if params.get("TaskInfos") is not None:
            self.TaskInfos = []
            for item in params.get("TaskInfos"):
                obj = CreateStructureTaskInfo()
                obj._deserialize(item)
                self.TaskInfos.append(obj)
        self.PolicyId = params.get("PolicyId")
        self.TriggerType = params.get("TriggerType")
        self.InsuranceTypes = params.get("InsuranceTypes")
        self.CallbackUrl = params.get("CallbackUrl")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateStructureTaskResponse(AbstractModel):
    """CreateStructureTask返回参数结构体

    """

    def __init__(self):
        """
        :param MainTaskId: 创建的主任务号，用于查询结果\n        :type MainTaskId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.MainTaskId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.MainTaskId = params.get("MainTaskId")
        self.RequestId = params.get("RequestId")


class CreateStructureTaskTestRequest(AbstractModel):
    """CreateStructureTaskTest请求参数结构体

    """

    def __init__(self):
        """
        :param ServiceType: 服务类型
Structured 仅结构化
Underwrite 结构化+核保\n        :type ServiceType: str\n        :param TaskInfos: 创建任务时可以上传多个报告，后台生成多个识别子任务，子任务的详细信息\n        :type TaskInfos: list of CreateStructureTaskInfo\n        :param PolicyId: 保单号\n        :type PolicyId: str\n        :param TriggerType: 核保触发方式
Auto 自动
Manual 手动\n        :type TriggerType: str\n        :param InsuranceTypes: 险种，如果是体检报告类型，此参数是必填，类型说明如下：
CriticalDiseaseInsurance:重疾险
LifeInsurance：寿险
AccidentInsurance：意外险\n        :type InsuranceTypes: list of str\n        :param CallbackUrl: 回调地址，接收Post请求传送结果\n        :type CallbackUrl: str\n        """
        self.ServiceType = None
        self.TaskInfos = None
        self.PolicyId = None
        self.TriggerType = None
        self.InsuranceTypes = None
        self.CallbackUrl = None


    def _deserialize(self, params):
        self.ServiceType = params.get("ServiceType")
        if params.get("TaskInfos") is not None:
            self.TaskInfos = []
            for item in params.get("TaskInfos"):
                obj = CreateStructureTaskInfo()
                obj._deserialize(item)
                self.TaskInfos.append(obj)
        self.PolicyId = params.get("PolicyId")
        self.TriggerType = params.get("TriggerType")
        self.InsuranceTypes = params.get("InsuranceTypes")
        self.CallbackUrl = params.get("CallbackUrl")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateStructureTaskTestResponse(AbstractModel):
    """CreateStructureTaskTest返回参数结构体

    """

    def __init__(self):
        """
        :param MainTaskId: 创建的主任务号，用于查询结果\n        :type MainTaskId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.MainTaskId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.MainTaskId = params.get("MainTaskId")
        self.RequestId = params.get("RequestId")


class DescribeStructCompareDataRequest(AbstractModel):
    """DescribeStructCompareData请求参数结构体

    """

    def __init__(self):
        """
        :param MainTaskId: 主任务号\n        :type MainTaskId: str\n        :param SubTaskId: 子任务号\n        :type SubTaskId: str\n        """
        self.MainTaskId = None
        self.SubTaskId = None


    def _deserialize(self, params):
        self.MainTaskId = params.get("MainTaskId")
        self.SubTaskId = params.get("SubTaskId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeStructCompareDataResponse(AbstractModel):
    """DescribeStructCompareData返回参数结构体

    """

    def __init__(self):
        """
        :param PolicyId: 保单号\n        :type PolicyId: str\n        :param MainTaskId: 主任务号\n        :type MainTaskId: str\n        :param CustomerId: 客户号
注意：此字段可能返回 null，表示取不到有效值。\n        :type CustomerId: str\n        :param CustomerName: 客户姓名
注意：此字段可能返回 null，表示取不到有效值。\n        :type CustomerName: str\n        :param ReviewTime: 复核时间\n        :type ReviewTime: str\n        :param MachineResult: 算法识别结果\n        :type MachineResult: str\n        :param ManualResult: 人工复核结果\n        :type ManualResult: str\n        :param Metrics: 结构化对比指标数据\n        :type Metrics: :class:`tencentcloud.cii.v20210408.models.CompareMetricsData`\n        :param NewItems: 新增项\n        :type NewItems: str\n        :param ModifyItems: 修改项\n        :type ModifyItems: str\n        :param SubTaskId: 子任务号\n        :type SubTaskId: str\n        :param AllTasks: 所有的子任务\n        :type AllTasks: list of ReviewDataTaskInfo\n        :param TaskType: 任务类型\n        :type TaskType: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.PolicyId = None
        self.MainTaskId = None
        self.CustomerId = None
        self.CustomerName = None
        self.ReviewTime = None
        self.MachineResult = None
        self.ManualResult = None
        self.Metrics = None
        self.NewItems = None
        self.ModifyItems = None
        self.SubTaskId = None
        self.AllTasks = None
        self.TaskType = None
        self.RequestId = None


    def _deserialize(self, params):
        self.PolicyId = params.get("PolicyId")
        self.MainTaskId = params.get("MainTaskId")
        self.CustomerId = params.get("CustomerId")
        self.CustomerName = params.get("CustomerName")
        self.ReviewTime = params.get("ReviewTime")
        self.MachineResult = params.get("MachineResult")
        self.ManualResult = params.get("ManualResult")
        if params.get("Metrics") is not None:
            self.Metrics = CompareMetricsData()
            self.Metrics._deserialize(params.get("Metrics"))
        self.NewItems = params.get("NewItems")
        self.ModifyItems = params.get("ModifyItems")
        self.SubTaskId = params.get("SubTaskId")
        if params.get("AllTasks") is not None:
            self.AllTasks = []
            for item in params.get("AllTasks"):
                obj = ReviewDataTaskInfo()
                obj._deserialize(item)
                self.AllTasks.append(obj)
        self.TaskType = params.get("TaskType")
        self.RequestId = params.get("RequestId")


class DescribeStructureResultRequest(AbstractModel):
    """DescribeStructureResult请求参数结构体

    """

    def __init__(self):
        """
        :param MainTaskId: 创建任务时返回的主任务ID\n        :type MainTaskId: str\n        """
        self.MainTaskId = None


    def _deserialize(self, params):
        self.MainTaskId = params.get("MainTaskId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeStructureResultResponse(AbstractModel):
    """DescribeStructureResult返回参数结构体

    """

    def __init__(self):
        """
        :param Status: 结果状态：
0：返回成功
1：结果未生成
2：结果生成失败\n        :type Status: int\n        :param Results: 结构化结果\n        :type Results: list of StructureResultObject\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Status = None
        self.Results = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Status = params.get("Status")
        if params.get("Results") is not None:
            self.Results = []
            for item in params.get("Results"):
                obj = StructureResultObject()
                obj._deserialize(item)
                self.Results.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeStructureTaskResultRequest(AbstractModel):
    """DescribeStructureTaskResult请求参数结构体

    """

    def __init__(self):
        """
        :param MainTaskId: 结构化任务ID\n        :type MainTaskId: str\n        """
        self.MainTaskId = None


    def _deserialize(self, params):
        self.MainTaskId = params.get("MainTaskId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeStructureTaskResultResponse(AbstractModel):
    """DescribeStructureTaskResult返回参数结构体

    """

    def __init__(self):
        """
        :param Status: 结果状态：
0：返回成功
1：结果未生成
2：结果生成失败\n        :type Status: int\n        :param Results: 结构化识别结果数组，每个数组元素对应一个图片的结构化结果，顺序和输入参数的ImageList或FileList对应。
注意：此字段可能返回 null，表示取不到有效值。\n        :type Results: list of ResultObject\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Status = None
        self.Results = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Status = params.get("Status")
        if params.get("Results") is not None:
            self.Results = []
            for item in params.get("Results"):
                obj = ResultObject()
                obj._deserialize(item)
                self.Results.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeStructureTaskResultTestRequest(AbstractModel):
    """DescribeStructureTaskResultTest请求参数结构体

    """

    def __init__(self):
        """
        :param MainTaskId: 结构化任务ID\n        :type MainTaskId: str\n        """
        self.MainTaskId = None


    def _deserialize(self, params):
        self.MainTaskId = params.get("MainTaskId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeStructureTaskResultTestResponse(AbstractModel):
    """DescribeStructureTaskResultTest返回参数结构体

    """

    def __init__(self):
        """
        :param Status: 结果状态：
0：返回成功
1：结果未生成
2：结果生成失败\n        :type Status: int\n        :param Results: 结构化识别结果数组，每个数组元素对应一个图片的结构化结果，顺序和输入参数的ImageList或FileList对应。
注意：此字段可能返回 null，表示取不到有效值。\n        :type Results: list of ResultObject\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Status = None
        self.Results = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Status = params.get("Status")
        if params.get("Results") is not None:
            self.Results = []
            for item in params.get("Results"):
                obj = ResultObject()
                obj._deserialize(item)
                self.Results.append(obj)
        self.RequestId = params.get("RequestId")


class ResultObject(AbstractModel):
    """用于返回结构化任务结果

    """

    def __init__(self):
        """
        :param Quality: 图片质量分\n        :type Quality: float\n        :param StructureResult: 由结构化算法结构化json转换的字符串，具体协议参见算法结构化结果协议\n        :type StructureResult: str\n        """
        self.Quality = None
        self.StructureResult = None


    def _deserialize(self, params):
        self.Quality = params.get("Quality")
        self.StructureResult = params.get("StructureResult")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ReviewDataTaskInfo(AbstractModel):
    """人工复核数据的子任务信息

    """

    def __init__(self):
        """
        :param MainTaskId: 主任务号\n        :type MainTaskId: str\n        :param SubTaskId: 子任务号\n        :type SubTaskId: str\n        :param TaskName: 任务名\n        :type TaskName: str\n        :param TaskType: 任务类型\n        :type TaskType: str\n        """
        self.MainTaskId = None
        self.SubTaskId = None
        self.TaskName = None
        self.TaskType = None


    def _deserialize(self, params):
        self.MainTaskId = params.get("MainTaskId")
        self.SubTaskId = params.get("SubTaskId")
        self.TaskName = params.get("TaskName")
        self.TaskType = params.get("TaskType")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class StructureResultObject(AbstractModel):
    """结构化结果

    """

    def __init__(self):
        """
        :param Code: 0表示正常返回\n        :type Code: int\n        :param TaskType: 报告类型\n        :type TaskType: str\n        :param StructureResult: 结构化结果\n        :type StructureResult: str\n        """
        self.Code = None
        self.TaskType = None
        self.StructureResult = None


    def _deserialize(self, params):
        self.Code = params.get("Code")
        self.TaskType = params.get("TaskType")
        self.StructureResult = params.get("StructureResult")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        